@@ -6,5 +6,8 @@
 chmod +x debian/rules
 dpkg-buildpackage -rfakeroot -i -I.git
 # for updating from scratchbox to my personal device
-scp ../invar_0.1.0_armel.deb root@10.0.0.8:/root/invar_0.1.0_armel.deb
-ssh root@10.0.0.8 "dpkg -i invar_0.1.0_armel.deb"
+scp ../libliqbase1_0.3.65_armel.deb root@10.0.0.8:/root
+ssh root@10.0.0.8 "dpkg -i libliqbase1_0.3.65_armel.deb"
+
+
+
