@@ -48,6 +48,10 @@
 #include "liqapp_prefs.h"
 #include "liqapp_hildon.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 liqcell *liqapp_logbase=NULL;
 
 liqapp app={0};
@@ -60,7 +64,7 @@ void * liqapp_log_context=NULL;
 
 void liqapp_log_setforwarding( void *logfunction_voidpcontext_strtime_strmsg, void *contextdata )
 {
-    liqapp_log_forwarding = logfunction_voidpcontext_strtime_strmsg;
+    liqapp_log_forwarding = (int (*)(void*, char*, char*))logfunction_voidpcontext_strtime_strmsg;
     liqapp_log_context=contextdata;
 }
 
@@ -111,11 +115,12 @@ char *liqapp_gettitle()
 //#######################################################################
 
 	static const char *hardware_product_filename = "/proc/component_version";
-    static char *hardware_product[32]={0};
+    static char hardware_product[32]={0};
 	static int   hardware_product_ispowerful;
 	int hardware_product_read()
 	{
-        hardware_product[0]=0;
+        hardware_product[0]=' ';		// we call through this function exactly once
+        hardware_product[1]=0;			// if it fails, there is no need to repeat in this case.
 		FILE *fd;
 		int rs;
 		fd = fopen(hardware_product_filename, "r");
@@ -147,20 +152,18 @@ char *liqapp_gettitle()
         return 0;
 	}
 
-/**
- * hardware_product_read return the "product" field from /proc/component_version
- * @return string containing product field "RX-44" etc
- */
-
-
-	char * liqapp_hardware_product_get()
+    /**
+     * hardware_product_read return the "product" field from /proc/component_version
+     * @return string containing product field "RX-44" etc
+     */
+    const char *liqapp_hardware_product_get()
     {
         if(hardware_product[0]==0)
         {
 			hardware_product_ispowerful = 0;
 			
             if( hardware_product_read() != 0 )
-				return NULL;
+				return "";
 			
 			// quick check for devices we know require limiting
 			
@@ -285,7 +288,7 @@ int liqapp_getopt_find(char *optname)
 		for(opt=1;opt<app.argc;opt++)
 		{	
 			char *label=app.argv[opt];
-			if( label[0] == '-'   &&   (strcmp( &label[1] , optname )==0) )
+			if( label[0] == '-'   &&  label[1] == '-' && (strcmp( &label[2] , optname )==0) )
 			{
 				return opt;
 			}
@@ -359,7 +362,7 @@ int res = strtol(param, &paramend, 0);
  * @return int 1 if success, 0 otherwise
  */
 
-int liqapp_folderexists(char *pathname)
+int liqapp_folderexists(const char *pathname)
 {
 	struct stat     statbuf;
 	if(stat(pathname, &statbuf) == -1)
@@ -381,7 +384,7 @@ int liqapp_folderexists(char *pathname)
  * @return int 1 if success, 0 otherwise
  */
 
-int liqapp_pathexists(char *pathname)
+int liqapp_pathexists(const char *pathname)
 {
 	struct stat     statbuf;
 	if(stat(pathname, &statbuf) == -1)
@@ -396,7 +399,7 @@ int liqapp_pathexists(char *pathname)
  * @param char *filename including path
  * @return int 1 if success, 0 otherwise
  */
-int liqapp_fileexists(char *filename)
+int liqapp_fileexists(const char *filename)
 {
 	struct stat     statbuf;
 	if(stat(filename, &statbuf) == -1)
@@ -418,7 +421,7 @@ int liqapp_fileexists(char *filename)
  * @param char *filename including path
  * @return int size if success, -1 otherwise
  */
-int liqapp_filesize(char *filename)
+int liqapp_filesize(const char *filename)
 {
 	struct stat     statbuf;
 	if(stat(filename, &statbuf) == -1)
@@ -436,14 +439,14 @@ int liqapp_filesize(char *filename)
  * @param char *filename including path
  * @return char * to the first character of the filename itself, or to the start of the filename if no '/' detected 
  */
-char *liqapp_filename_walkoverpath(char *filename)
+const char *liqapp_filename_walkoverpath(const char *filename)
 {
 	if(!filename || *filename==0)
 	{
 		return filename;
 	}
-	char *fnstart = filename;
-	char *fnend  = filename;
+	const char *fnstart = filename;
+	const char *fnend  = filename;
 	// walk quickly to the end
 	while(*fnend)
 	{
@@ -453,12 +456,13 @@ char *liqapp_filename_walkoverpath(char *filename)
 	}
 	return fnstart;
 }
+
 /**
  * find and return the extension part of a filename
  * @param char *filename to get the extension from
  * @return char * to the first character of the extension, or to the start of the filename if no '.' detected 
  */
-char *liqapp_filename_walktoextension(char *filename)
+const char *liqapp_filename_walktoextension(const char *filename)
 {
 	filename = liqapp_filename_walkoverpath(filename);
 	
@@ -467,8 +471,8 @@ char *liqapp_filename_walktoextension(char *filename)
 		return filename;
 	}
 	
-	char *fnstart = filename;
-	char *fnend  = filename;
+	const char *fnstart = filename;
+	const char *fnend  = filename;
 	// walk quickly to the end
 	while(*fnend)
 	{
@@ -481,7 +485,7 @@ char *liqapp_filename_walktoextension(char *filename)
 
 
 //http://www.koders.com/cpp/fid0B921B251D9F6C17A083FBD5C9565285C637C785.aspx?s=md5
-int liqapp_file_copy (char * from, char * to, int allowoverwrite)
+int liqapp_file_copy (const char * from, const char * to, int allowoverwrite)
 {
     size_t nmemb;
     //int nmemb;
@@ -527,6 +531,21 @@ int liqapp_file_copy (char * from, char * to, int allowoverwrite)
 
 
 
+	
+static int trymakepath(char *path)
+{
+	if(!liqapp_pathexists(path))
+	{
+		int status;
+		status = mkdir(path, S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH);
+		if(status)
+		{
+			liqapp_log("liqapp error: could not mkdir '%s'",path);
+			return -1;			
+		}
+	}
+	return 0;
+}
 
 //#######################################################################
 //####################################################################### app init
@@ -542,7 +561,7 @@ int liqapp_file_copy (char * from, char * to, int allowoverwrite)
  * @param version The version of the application
  * @return int 0 for success
  */
-int 		liqapp_init(int argc, char* argv[],char *title,char *version)
+int 		liqapp_init(int argc, char* argv[], const char *title, const char *version)
 {
 	
 
@@ -601,7 +620,17 @@ int 		liqapp_init(int argc, char* argv[],char *title,char *version)
 	liqapp_log("You passed %i arguments",argc);
 	int i;
 	for(i=0;i<argc;i++)
+	{
 		liqapp_log("Argument %i = %s",i,argv[i]);
+		if( strcmp(argv[i],"--showdebugboxes")==0)
+		{
+			liqcell_showdebugboxes = 1;
+		}
+		if( strcmp(argv[i],"--showfps")==0)
+		{
+			liqcell_showfps = 1;
+		}		
+	}
 
 
 
@@ -622,7 +651,7 @@ int 		liqapp_init(int argc, char* argv[],char *title,char *version)
 	}
 	
 
-	char *envhome = getenv("HOME");
+	const char *envhome = getenv("HOME");
 	if(!envhome)
 	{
 		// wrong, but will suffice
@@ -658,23 +687,6 @@ int 		liqapp_init(int argc, char* argv[],char *title,char *version)
 
 	//####################################################### make sure our data folder exists
 
-	
-		int trymakepath(char *path)
-		{
-			if(!liqapp_pathexists(path))
-			{
-				int status;
-				status = mkdir(buf, S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH);
-				if(status)
-				{
-					liqapp_log("liqapp error: could not mkdir '%s'",path);
-					return -1;			
-				}
-			}
-			return 0;
-		}
-
-
 	snprintf(buf,FILENAME_MAX,"%s",app.userdatapath);
 	trymakepath(buf);
 
@@ -735,7 +747,10 @@ int 		liqapp_init(int argc, char* argv[],char *title,char *version)
 	liqapp_log("#############");
 	liqapp_log("app.username     =%s",app.username);
 	liqapp_log("#############");
-
+	
+	liqcell_showfps =        1 == atoi(liqapp_pref_getvalue_def("showfps","0"));
+	liqcell_showdebugboxes = 1 == atoi(liqapp_pref_getvalue_def("showdebugboxes","0"));
+	
 	return 0;
 	
 }
@@ -757,7 +772,7 @@ void liqapp_ensurecleanusername(char *usernamewhichismodifiable)
 }
 
 
-int liqapp_usernamechange(char *newusername)
+int liqapp_usernamechange(const char *newusername)
 {
     if(app.username){ free(app.username); app.username=NULL; }
     
@@ -776,7 +791,7 @@ static int liqapp_log_forwarding_count=0;
  * @param list of parameters for completing the formatting
  * @return int 0 for success
  */
-int liqapp_vdeeplog(char *logentry, va_list arg)
+int liqapp_vdeeplog(const char *logentry, va_list arg)
 {
     time_t     now;
     struct tm  *ts;
@@ -818,7 +833,7 @@ int liqapp_vdeeplog(char *logentry, va_list arg)
 	}
 	*/	
 	//printf("%s: %s: ",buf,app.title);
-	printf("%s ",buf);
+	printf("%s [%s] ",buf,app.username);
 
 	vprintf(logentry, arg);
 	
@@ -862,7 +877,7 @@ int liqapp_deeplog(char *logentry, ...)
  * @param list of parameters for completing the formatting
  * @return int 0 for success
  */
-int liqapp_log(char *logentry, ...)
+int liqapp_log(const char *logentry, ...)
 {
 	//return 0;
 	if(app.infologgingenabled==0) return 1;
@@ -882,10 +897,10 @@ int liqapp_log(char *logentry, ...)
  * @param logentry The error message to log
  * @return int returnstatus
  */
-int liqapp_errorandfail(int returnstatus,char *logentry)
+int liqapp_errorandfail(int returnstatus, const char *logentry)
 {
 	char buff[255];
-	char *syserror = strerror(errno); // Get latest system error, enhancement by Zach
+	const char *syserror = strerror(errno); // Get latest system error, enhancement by Zach
 	if(!syserror) syserror="*UNKNOWN ERROR*";
 	snprintf(buff,255,"FAILED: %i : %s : System Error : %s",returnstatus, logentry, syserror);
 	liqapp_deeplog(buff);
@@ -900,7 +915,7 @@ int liqapp_errorandfail(int returnstatus,char *logentry)
  * @param logentry The warning message to log
  * @return int returnstatus
  */
-int liqapp_warnandcontinue(int returnstatus,char *logentry)
+int liqapp_warnandcontinue(int returnstatus, const char *logentry)
 {
 	char buff[255];
 	snprintf(buff,255,"WARN: %i : %s",returnstatus,logentry);
@@ -941,26 +956,36 @@ int liqapp_close()
 // char datestamp[20];
 // liqapp_formatnow(datestamp,sizeof(datestamp),"yyyymmdd_hhmmss");
 
-int liqapp_formatnow(char *buffer,int buffersize,char *format)
+int liqapp_formatnow(char *buffer, int buffersize, const char *format)
 {
 
 	struct tm 	*local;
 	time_t 		t;
 	  			t = time(NULL);
 	  			local = localtime(&t);
-	
-	
+if(strcmp(format,"yyyymmdd_hhmmss")==0)
+{
 	snprintf(buffer,buffersize,"%04i%02i%02i_%02i%02i%02i", 
 			 1900+local->tm_year,
 			 local->tm_mon+1,			// damn 0 based month..
 			 local->tm_mday,
-			 
 			 local->tm_hour,
 			 local->tm_min,
 			 local->tm_sec
-			 
-			 
 			 );
+}
+else
+if(strcmp(format,"yyyy/mm/dd")==0)
+{
+	snprintf(buffer,buffersize,"%04i/%02i/%02i", 
+			 1900+local->tm_year,
+			 local->tm_mon+1,			// damn 0 based month..
+			 local->tm_mday
+			 );	
+}
+else
+	snprintf(buffer,buffersize,"need fix liqapp_formatnow"); 
+
 	return 0;
 }
 
@@ -1065,6 +1090,26 @@ char *stristr(const char *String, const char *Pattern)
 //		// invalid
 // }
 
+static int strncpy_onlydigits(char *res,char *indat,int size)
+{
+	int ch;
+	for(ch=0;ch<size;ch++)
+	{
+		if(isdigit(*indat))
+		{
+			*res++=*indat++;
+		}
+		else
+		{
+			return -1;
+		}
+	}
+	// null terminate
+	*res++=0;
+	return 0;
+}
+
+
 
 		int liqapp_datestamp_to_date(char *datestamp,struct tm *timebuf)		// convert a liqbase datestamp "yyyymmdd_hhmmss" into a tm struct
 		{
@@ -1077,24 +1122,7 @@ char *stristr(const char *String, const char *Pattern)
 			char SS[3]="00";
 			
 			char *indat=datestamp;
-			int strncpy_onlydigits(char *res,char *indat,int size)
-			{
-				int ch;
-				for(ch=0;ch<size;ch++)
-				{
-					if(isdigit(*indat))
-					{
-						*res++=*indat++;
-					}
-					else
-					{
-						return -1;
-					}
-				}
-				// null terminate
-				*res++=0;
-				return 0;
-			}
+
 			//liqapp_log("has yr? '%s'",indat);
 			if( strncpy_onlydigits(yy,indat,4) == 0 )
 			{
@@ -1190,7 +1218,11 @@ char *stristr(const char *String, const char *Pattern)
 
 		}
 			
-			
 		// similar code here
 		// http://www.velocityreviews.com/forums/t679803-time-issue-mktime-timet-tm.html
 		// found after trying to find problem
+		
+#ifdef __cplusplus
+}
+#endif
+
